@@ -11,12 +11,12 @@ build_time_vars = {'ABIFLAGS': 'm',
  'AST_C_DIR': 'Python',
  'AST_H': 'Include/Python-ast.h',
  'AST_H_DIR': 'Include',
- 'BASECFLAGS': '-Wno-unused-result',
+ 'BASECFLAGS': '-Wno-unused-result -Werror=declaration-after-statement',
  'BASECPPFLAGS': '',
  'BASEMODLIBS': '',
- 'BINDIR': '/opt/lib/python-3.3.3/bin',
- 'BINLIBDEST': '/opt/lib/python-3.3.3/lib/python3.3',
- 'BLDLIBRARY': 'libpython3.3m.a',
+ 'BINDIR': '/opt/lib/python-3.4.0/bin',
+ 'BINLIBDEST': '/opt/lib/python-3.4.0/lib/python3.4',
+ 'BLDLIBRARY': 'libpython3.4m.a',
  'BLDSHARED': 'gcc -pthread -shared',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
@@ -24,26 +24,39 @@ build_time_vars = {'ABIFLAGS': 'm',
  'BYTESTR_DEPS': '\\',
  'CC': 'gcc -pthread',
  'CCSHARED': '-fPIC',
- 'CFLAGS': '-Wno-unused-result -DNDEBUG -g -fwrapv -O3 -Wall -Wstrict-prototypes',
+ 'CFLAGS': '-Wno-unused-result -Werror=declaration-after-statement -DNDEBUG '
+           '-g -fwrapv -O3 -Wall -Wstrict-prototypes',
  'CFLAGSFORSHARED': '',
- 'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in Makefile.pre.in',
+ 'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
+                'Makefile.pre.in',
  'CONFIGURE_CFLAGS': '',
  'CONFIGURE_CPPFLAGS': '',
  'CONFIGURE_LDFLAGS': '',
- 'CONFIG_ARGS': "'--prefix=/opt/lib/python-3.3.3' '--enable-ipv6' '--enable-loadable-sqlite-extensions' '--with-dbmliborder=bdb' '--with-wide-unicode' '--with-computed-gotos' '--with-pymalloc'",
- 'CONFINCLUDEDIR': '/opt/lib/python-3.3.3/include',
- 'CONFINCLUDEPY': '/opt/lib/python-3.3.3/include/python3.3m',
+ 'CONFIG_ARGS': "'--prefix=/opt/lib/python-3.4.0' '--enable-ipv6' "
+                "'--enable-loadable-sqlite-extensions' "
+                "'--with-dbmliborder=bdb' '--with-wide-unicode' "
+                "'--with-computed-gotos' '--with-pymalloc'",
+ 'CONFINCLUDEDIR': '/opt/lib/python-3.4.0/include',
+ 'CONFINCLUDEPY': '/opt/lib/python-3.4.0/include/python3.4m',
  'COREPYTHONPATH': ':plat-linux',
+ 'COVERAGE_INFO': '/home/sources/packages/Python-3.4.0/coverage.info',
+ 'COVERAGE_REPORT': '/home/sources/packages/Python-3.4.0/lcov-report',
+ 'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
+                            'report"',
  'CPPFLAGS': '-I. -IInclude -I./Include',
  'CXX': 'g++ -pthread',
- 'DESTDIRS': '/opt/lib/python-3.3.3 /opt/lib/python-3.3.3/lib /opt/lib/python-3.3.3/lib/python3.3 /opt/lib/python-3.3.3/lib/python3.3/lib-dynload',
- 'DESTLIB': '/opt/lib/python-3.3.3/lib/python3.3',
+ 'DESTDIRS': '/opt/lib/python-3.4.0 /opt/lib/python-3.4.0/lib '
+             '/opt/lib/python-3.4.0/lib/python3.4 '
+             '/opt/lib/python-3.4.0/lib/python3.4/lib-dynload',
+ 'DESTLIB': '/opt/lib/python-3.4.0/lib/python3.4',
  'DESTPATH': '',
- 'DESTSHARED': '/opt/lib/python-3.3.3/lib/python3.3/lib-dynload',
+ 'DESTSHARED': '/opt/lib/python-3.4.0/lib/python3.4/lib-dynload',
  'DIRMODE': 755,
- 'DIST': 'README ChangeLog configure configure.ac acconfig.h pyconfig.h.in Makefile.pre.in Include Lib Misc Ext-dummy',
+ 'DIST': 'README ChangeLog configure configure.ac acconfig.h pyconfig.h.in '
+         'Makefile.pre.in Include Lib Misc Ext-dummy',
  'DISTDIRS': 'Include Lib Misc Ext-dummy',
- 'DISTFILES': 'README ChangeLog configure configure.ac acconfig.h pyconfig.h.in Makefile.pre.in',
+ 'DISTFILES': 'README ChangeLog configure configure.ac acconfig.h '
+              'pyconfig.h.in Makefile.pre.in',
  'DLINCLDIR': '.',
  'DLLLIBRARY': '',
  'DOUBLE_IS_ARM_MIXED_ENDIAN_IEEE754': 0,
@@ -51,13 +64,14 @@ build_time_vars = {'ABIFLAGS': 'm',
  'DOUBLE_IS_LITTLE_ENDIAN_IEEE754': 1,
  'DYNLOADFILE': 'dynload_shlib.o',
  'ENABLE_IPV6': 1,
+ 'ENSUREPIP': 'upgrade',
  'EXE': '',
  'EXEMODE': 755,
  'EXTRAMACHDEPPATH': '',
  'EXTRAPLATDIR': '@EXTRAPLATDIR@',
  'EXTRATESTOPTS': '',
  'EXTRA_CFLAGS': '',
- 'EXT_SUFFIX': '.cpython-33m.so',
+ 'EXT_SUFFIX': '.cpython-34m.so',
  'FILEMODE': 644,
  'FLOCK_NEEDS_LIBBSD': 0,
  'GETPGRP_HAVE_ARG': 0,
@@ -70,12 +84,12 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_ACOSH': 1,
  'HAVE_ADDRINFO': 1,
  'HAVE_ALARM': 1,
+ 'HAVE_ALIGNED_REQUIRED': 0,
  'HAVE_ALLOCA_H': 1,
  'HAVE_ALTZONE': 0,
  'HAVE_ASINH': 1,
  'HAVE_ASM_TYPES_H': 1,
  'HAVE_ATANH': 1,
- 'HAVE_ATTRIBUTE_FORMAT_PARSETUPLE': 0,
  'HAVE_BIND_TEXTDOMAIN_CODESET': 1,
  'HAVE_BLUETOOTH_BLUETOOTH_H': 0,
  'HAVE_BLUETOOTH_H': 0,
@@ -117,7 +131,9 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_DLFCN_H': 1,
  'HAVE_DLOPEN': 1,
  'HAVE_DUP2': 1,
+ 'HAVE_DUP3': 1,
  'HAVE_DYNAMIC_LOADING': 1,
+ 'HAVE_ENDIAN_H': 1,
  'HAVE_EPOLL': 1,
  'HAVE_EPOLL_CREATE1': 1,
  'HAVE_ERF': 1,
@@ -158,7 +174,6 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_GCC_ASM_FOR_X87': 1,
  'HAVE_GCC_UINT128_T': 1,
  'HAVE_GETADDRINFO': 1,
- 'HAVE_GETCWD': 1,
  'HAVE_GETC_UNLOCKED': 1,
  'HAVE_GETGROUPLIST': 1,
  'HAVE_GETGROUPS': 1,
@@ -188,6 +203,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_GLIBC_MEMMOVE_BUG': 0,
  'HAVE_GRP_H': 1,
  'HAVE_HSTRERROR': 1,
+ 'HAVE_HTOLE64': 1,
  'HAVE_HYPOT': 1,
  'HAVE_IEEEFP_H': 0,
  'HAVE_IF_NAMEINDEX': 1,
@@ -218,6 +234,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_LIBUTIL_H': 0,
  'HAVE_LINK': 1,
  'HAVE_LINKAT': 1,
+ 'HAVE_LINUX_CAN_BCM_H': 0,
  'HAVE_LINUX_CAN_H': 1,
  'HAVE_LINUX_CAN_RAW_H': 1,
  'HAVE_LINUX_NETLINK_H': 1,
@@ -259,6 +276,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_POSIX_FADVISE': 1,
  'HAVE_POSIX_FALLOCATE': 1,
  'HAVE_PREAD': 1,
+ 'HAVE_PRLIMIT': 0,
  'HAVE_PROCESS_H': 0,
  'HAVE_PROTOTYPES': 1,
  'HAVE_PTHREAD_ATFORK': 1,
@@ -357,6 +375,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_SYS_BSDTTY_H': 0,
  'HAVE_SYS_DEVPOLL_H': 0,
  'HAVE_SYS_DIR_H': 0,
+ 'HAVE_SYS_ENDIAN_H': 0,
  'HAVE_SYS_EPOLL_H': 1,
  'HAVE_SYS_EVENT_H': 0,
  'HAVE_SYS_FILE_H': 1,
@@ -421,6 +440,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_WCSCOLL': 1,
  'HAVE_WCSFTIME': 1,
  'HAVE_WCSXFRM': 1,
+ 'HAVE_WMEMCMP': 1,
  'HAVE_WORKING_TZSET': 1,
  'HAVE_WRITEV': 1,
  'HAVE_ZLIB_COPY': 1,
@@ -429,40 +449,44 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HGTAG': '',
  'HGVERSION': '',
  'HOST_GNU_TYPE': 'x86_64-unknown-linux-gnu',
- 'INCLDIRSTOMAKE': '/opt/lib/python-3.3.3/include /opt/lib/python-3.3.3/include /opt/lib/python-3.3.3/include/python3.3m /opt/lib/python-3.3.3/include/python3.3m',
- 'INCLUDEDIR': '/opt/lib/python-3.3.3/include',
- 'INCLUDEPY': '/opt/lib/python-3.3.3/include/python3.3m',
+ 'INCLDIRSTOMAKE': '/opt/lib/python-3.4.0/include '
+                   '/opt/lib/python-3.4.0/include '
+                   '/opt/lib/python-3.4.0/include/python3.4m '
+                   '/opt/lib/python-3.4.0/include/python3.4m',
+ 'INCLUDEDIR': '/opt/lib/python-3.4.0/include',
+ 'INCLUDEPY': '/opt/lib/python-3.4.0/include/python3.4m',
  'INSTALL': '/usr/bin/install -c',
  'INSTALL_DATA': '/usr/bin/install -c -m 644',
  'INSTALL_PROGRAM': '/usr/bin/install -c',
  'INSTALL_SCRIPT': '/usr/bin/install -c',
  'INSTALL_SHARED': '/usr/bin/install -c -m 555',
- 'INSTSONAME': 'libpython3.3m.a',
+ 'INSTSONAME': 'libpython3.4m.a',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
  'LDCXXSHARED': 'g++ -pthread -shared',
  'LDFLAGS': '',
  'LDLAST': '',
- 'LDLIBRARY': 'libpython3.3m.a',
+ 'LDLIBRARY': 'libpython3.4m.a',
  'LDLIBRARYDIR': '',
  'LDSHARED': 'gcc -pthread -shared',
- 'LDVERSION': '3.3m',
+ 'LDVERSION': '3.4m',
  'LIBC': '',
- 'LIBDEST': '/opt/lib/python-3.3.3/lib/python3.3',
- 'LIBDIR': '/opt/lib/python-3.3.3/lib',
+ 'LIBDEST': '/opt/lib/python-3.4.0/lib/python3.4',
+ 'LIBDIR': '/opt/lib/python-3.4.0/lib',
  'LIBFFI_INCLUDEDIR': '',
  'LIBM': '-lm',
  'LIBOBJDIR': 'Python/',
  'LIBOBJS': '',
- 'LIBPC': '/opt/lib/python-3.3.3/lib/pkgconfig',
- 'LIBPL': '/opt/lib/python-3.3.3/lib/python3.3/config-3.3m',
- 'LIBRARY': 'libpython3.3m.a',
+ 'LIBPC': '/opt/lib/python-3.4.0/lib/pkgconfig',
+ 'LIBPL': '/opt/lib/python-3.4.0/lib/python3.4/config-3.4m',
+ 'LIBRARY': 'libpython3.4m.a',
  'LIBRARY_OBJS': '\\',
  'LIBRARY_OBJS_OMIT_FROZEN': '\\',
  'LIBS': '-lpthread -ldl  -lutil',
  'LIBSUBDIRS': 'tkinter tkinter/test tkinter/test/test_tkinter \\',
  'LINKCC': 'gcc -pthread',
  'LINKFORSHARED': '-Xlinker -export-dynamic',
+ 'LIPO_32BIT_FLAGS': '',
  'LN': 'ln',
  'LOCALMODLIBS': '',
  'LOG1P_DROPS_ZERO_SIGN': 0,
@@ -470,16 +494,29 @@ build_time_vars = {'ABIFLAGS': 'm',
  'MACHDEPPATH': ':plat-linux',
  'MACHDEPS': 'plat-linux @EXTRAPLATDIR@',
  'MACHDEP_OBJS': '',
- 'MACHDESTLIB': '/opt/lib/python-3.3.3/lib/python3.3',
+ 'MACHDESTLIB': '/opt/lib/python-3.4.0/lib/python3.4',
  'MACOSX_DEPLOYMENT_TARGET': '',
  'MAINCC': 'gcc -pthread',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 0,
  'MAKESETUP': './Modules/makesetup',
- 'MANDIR': '/opt/lib/python-3.3.3/share/man',
+ 'MANDIR': '/opt/lib/python-3.4.0/share/man',
  'MKDIR_P': '/bin/mkdir -p',
  'MODLIBS': '',
- 'MODOBJS': 'Modules/_threadmodule.o  Modules/signalmodule.o  Modules/posixmodule.o  Modules/errnomodule.o  Modules/pwdmodule.o  Modules/_sre.o  Modules/_codecsmodule.o  Modules/_weakref.o  Modules/_functoolsmodule.o  Modules/operator.o  Modules/_collectionsmodule.o  Modules/itertoolsmodule.o  Modules/_localemodule.o  Modules/_iomodule.o Modules/iobase.o Modules/fileio.o Modules/bytesio.o Modules/bufferedio.o Modules/textio.o Modules/stringio.o  Modules/zipimport.o  Modules/faulthandler.o  Modules/symtablemodule.o  Modules/xxsubtype.o',
+ 'MODOBJS': 'Modules/_threadmodule.o  Modules/signalmodule.o  '
+            'Modules/md5module.o  Modules/sha1module.o  '
+            'Modules/sha256module.o  Modules/sha512module.o  '
+            'Modules/posixmodule.o  Modules/errnomodule.o  '
+            'Modules/pwdmodule.o  Modules/_sre.o  Modules/_codecsmodule.o  '
+            'Modules/_weakref.o  Modules/_functoolsmodule.o  '
+            'Modules/_operator.o  Modules/_collectionsmodule.o  '
+            'Modules/itertoolsmodule.o  Modules/atexitmodule.o  '
+            'Modules/_stat.o  Modules/_localemodule.o  Modules/_iomodule.o '
+            'Modules/iobase.o Modules/fileio.o Modules/bytesio.o '
+            'Modules/bufferedio.o Modules/textio.o Modules/stringio.o  '
+            'Modules/zipimport.o  Modules/faulthandler.o  '
+            'Modules/_tracemalloc.o Modules/hashtable.o  '
+            'Modules/symtablemodule.o  Modules/xxsubtype.o',
  'MODULE_OBJS': '\\',
  'MULTIARCH': '',
  'MVWDELCH_IS_EXPRESSION': 1,
@@ -521,21 +558,25 @@ build_time_vars = {'ABIFLAGS': 'm',
  'PYTHON_FOR_BUILD': './python -E',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
- 'PY_CFLAGS': '-Wno-unused-result -DNDEBUG -g -fwrapv -O3 -Wall -Wstrict-prototypes',
- 'PY_CORE_CFLAGS': '-Wno-unused-result -DNDEBUG -g -fwrapv -O3 -Wall -Wstrict-prototypes -I. -IInclude -I./Include  -DPy_BUILD_CORE',
+ 'PY_CFLAGS': '-Wno-unused-result -Werror=declaration-after-statement '
+              '-DNDEBUG -g -fwrapv -O3 -Wall -Wstrict-prototypes',
+ 'PY_CORE_CFLAGS': '-Wno-unused-result -Werror=declaration-after-statement '
+                   '-DNDEBUG -g -fwrapv -O3 -Wall -Wstrict-prototypes -I. '
+                   '-IInclude -I./Include  -DPy_BUILD_CORE',
  'PY_CPPFLAGS': '-I. -IInclude -I./Include',
  'PY_FORMAT_LONG_LONG': '"ll"',
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_LDFLAGS': '',
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 0,
+ 'Py_HASH_ALGORITHM': 0,
  'QUICKTESTOPTS': '-x test_subprocess test_io test_lib2to3 \\',
  'RANLIB': 'ranlib',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
  'RUNSHARED': '',
- 'SCRIPTDIR': '/opt/lib/python-3.3.3/lib',
+ 'SCRIPTDIR': '/opt/lib/python-3.4.0/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SGI_ABI': '',
  'SHELL': '/bin/sh',
@@ -561,12 +602,12 @@ build_time_vars = {'ABIFLAGS': 'm',
  'SIZEOF_VOID_P': 8,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
- 'SO': '.so',
- 'SOABI': 'cpython-33m',
+ 'SOABI': 'cpython-34m',
  'SRCDIRS': 'Parser Grammar Objects Python Modules Mac',
  'SRC_GDB_HOOKS': './Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
+ 'STRIPFLAG': '-s',
  'SUBDIRS': '',
  'SUBDIRSTOO': 'Include Lib Misc',
  'SYSLIBS': '-lm',
@@ -584,12 +625,12 @@ build_time_vars = {'ABIFLAGS': 'm',
  'TIMEMODULE_LIB': 'rt',
  'TIME_WITH_SYS_TIME': 1,
  'TM_IN_SYS_TIME': 0,
- 'UNICODE_DEPS': '\\ \\',
+ 'UNICODE_DEPS': '\\',
  'UNIVERSALSDK': '',
  'USE_COMPUTED_GOTOS': 1,
  'USE_INLINE': 1,
  'VA_LIST_IS_ARRAY': 1,
- 'VERSION': '3.3',
+ 'VERSION': '3.4',
  'WANT_SIGFPE_HANDLER': 0,
  'WINDOW_HAS_FLAGS': 1,
  'WITH_DOC_STRINGS': 1,
@@ -602,9 +643,9 @@ build_time_vars = {'ABIFLAGS': 'm',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/home/sources/packages/Python-3.3.3',
- 'abs_srcdir': '/home/sources/packages/Python-3.3.3',
- 'datarootdir': '/opt/lib/python-3.3.3/share',
- 'exec_prefix': '/opt/lib/python-3.3.3',
- 'prefix': '/opt/lib/python-3.3.3',
+ 'abs_builddir': '/home/sources/packages/Python-3.4.0',
+ 'abs_srcdir': '/home/sources/packages/Python-3.4.0',
+ 'datarootdir': '/opt/lib/python-3.4.0/share',
+ 'exec_prefix': '/opt/lib/python-3.4.0',
+ 'prefix': '/opt/lib/python-3.4.0',
  'srcdir': '.'}
